firkin-single-node 0.0.1-alpha

Production Apple/VZ runtime composition for the firkin Rust containerization library
docs.rs failed to build firkin-single-node-0.0.1-alpha
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.

Single-node Apple/VZ runtime composition.

This module is the product-neutral boundary for local runtime orchestration. Product APIs such as Cube map their request and response DTOs to this surface.